@@ -11,11 +11,12 @@ use diagnostics;
 BEGIN { $| = 1; print "1..7\n"; }
 END {print "not ok 1\n" unless $loaded;}
 use lib 'lib', 'blib';
-use File::Sort 0.18;
-use File::Sort qw(sort_file);
+use File::Sort 0.18 qw(sort_file);
 $loaded = 1;
 print "ok 1\n";
 
+my $D = 0;
+
 ######################### End of black magic.
 
 # Insert your test code below (better if it prints "ok 13"
@@ -23,7 +24,7 @@ print "ok 1\n";
 # of the test code):
 
 
-{
+if (1) {
 	my $fail1 = 0;
 	my $fail2 = 0;
 	my @files = qw(
@@ -32,8 +33,8 @@ print "ok 1\n";
 		Sort.pm_rsorted
 		Sort.pm_rsorted.txt
   	);
-	sort_file({I=>'Sort.pm_unsorted.txt', O=>$files[0]});
-	sort_file({I=>'Sort.pm_unsorted.txt', O=>$files[2], R=>1});
+	sort_file({I=>'Sort.pm_unsorted.txt', o=>$files[0], D=>$D});
+	sort_file({I=>'Sort.pm_unsorted.txt', o=>$files[2], r=>1, D=>$D});
 
 	open(F0, $files[0])	|| $fail1++;
 	open(F1, $files[1])	|| $fail1++;
@@ -41,15 +42,13 @@ print "ok 1\n";
 	open(F3, $files[3])	|| $fail2++;
 	while(<F1>) {
 		chomp;
-		my $l = <F0>;
-		($fail1++ && last) if !defined($l);
+		defined(my $l = <F0>) or ($fail1++, last);
 		chomp($l);
 		$fail1++ if ($l ne $_);
 	}
 	while(<F3>) {
 		chomp;
-		my $l = <F2>;
-		($fail2++ && last) if !defined($l);
+		defined(my $l = <F2>) or ($fail2++, last);
 		chomp($l);
 		$fail2++ if ($l ne $_);
 	}
@@ -62,14 +61,14 @@ print "ok 1\n";
 	unlink(@files[0,2]) unless ($fail1 || $fail2);
 }
 
-{
+if (1) {
 	srand();
 	my $fail1 = 0;
 	my $fail2 = 0;
 	my @files = qw(
-		:test1
-		:test2
-		:test3
+		test10
+		test20
+		test30
 	);
 	my @lines;
 	for (0 .. 99) {
@@ -78,21 +77,20 @@ print "ok 1\n";
 	open(F0,">$files[0]") || ($fail1++ && $fail2++);
 	print F0 join("\n", @lines);
 	close(F0);
-	sort_file({I=>$files[0], O=>$files[1], N=>1, Y=>2});
-	sort_file({I=>$files[0], O=>$files[2], N=>1, R=>1, Y=>2});
+
+	sort_file({I=>$files[0], o=>$files[1], n=>1, 'y'=>2, D=>$D});
+	sort_file({I=>$files[0], o=>$files[2], n=>1, r=>1, 'y'=>2, D=>$D});
 
 	open(F1, $files[1])	|| $fail1++;
 	open(F2, $files[2])	|| $fail2++;
 
 	for (0 .. 99) {
-		my $l = <F1>;
-		($fail1++ && last) if !defined($l);
+		defined(my $l = <F1>) or ($fail1++, last);
 		chomp($l);
 		$fail1++ if ($l != $_);
 	}
 	for (reverse (0 .. 99)) {
-		my $l = <F2>;
-		($fail2++ && last) if !defined($l);
+		defined(my $l = <F2>) or ($fail2++, last);
 		chomp($l);
 		$fail2++ if ($l != $_);
 	}
@@ -101,14 +99,14 @@ print "ok 1\n";
 	unlink(@files) unless ($fail1 || $fail2);
 }
 
-{
+if (1) {
 	srand();
 	my $fail1 = 0;
 	my $fail2 = 0;
 	my @files = qw(
-		:test1
-		:test2
-		:test3
+		test11
+		test21
+		test31
 	);
 	my @lines;
 	for (0 .. 99) {
@@ -118,22 +116,20 @@ print "ok 1\n";
 	open(F0,">$files[0]") || ($fail1++ && $fail2++);
 	print F0 join("\n", @lines);
 	close(F0);
-	sort_file({I=>$files[0], O=>$files[1], N=>1, D=>'|', F=>1, Y=>3});
-	sort_file({I=>$files[0], O=>$files[2], N=>1, R=>1, D=>'|', F=>1, Y=>3});
+	sort_file({I=>$files[0], o=>$files[1], n=>1, t=>'|', k=>2, Y=>3, D=>$D});
+	sort_file({I=>$files[0], o=>$files[2], n=>1, r=>1, t=>'|', k=>2, Y=>3, D=>$D});
 	
 	open(F1, $files[1])	|| $fail1++;
 	open(F2, $files[2])	|| $fail2++;
 
 	for (0 .. 99) {
-		my $l = <F1>;
-		($fail1++ && last) if !defined($l);
+		defined(my $l = <F1>) or	($fail1++ or last);
 		chomp($l);
 		$_ = sprintf "%s|$_", $_%2;
 		$fail1++ if ($l ne $_);
 	}
 	for (reverse (0 .. 99)) {
-		my $l = <F2>;
-		($fail2++ && last) if !defined($l);
+		defined(my $l = <F2>) or ($fail2++, last);
 		chomp($l);
 		$_ = sprintf "%s|$_", $_%2;
 		$fail2++ if ($l ne $_);
